@@ -142,6 +142,15 @@ describe('bodyParser.json()', function () {
       test.expect(413, done)
     })
 
+    it('should 413 when inflated body over limit', function (done) {
+      var server = createServer({ limit: '1kb' })
+      var test = request(server).post('/')
+      test.set('Content-Encoding', 'gzip')
+      test.set('Content-Type', 'application/json')
+      test.write(Buffer.from('1f8b080000000000000aab562a2e2952b252d21b05a360148c58a0540b0066f7ce1e0a040000', 'hex'))
+      test.expect(413, done)
+    })
+
     it('should accept number of bytes', function (done) {
       var buf = Buffer.alloc(1024, '.')
       request(createServer({ limit: 1024 }))
@@ -390,9 +399,11 @@ describe('bodyParser.json()', function () {
     })
 
     it('should error from verify', function (done) {
-      var server = createServer({ verify: function (req, res, buf) {
-        if (buf[0] === 0x5b) throw new Error('no arrays')
-      } })
+      var server = createServer({
+        verify: function (req, res, buf) {
+          if (buf[0] === 0x5b) throw new Error('no arrays')
+        }
+      })
 
       request(server)
         .post('/')
@@ -402,9 +413,11 @@ describe('bodyParser.json()', function () {
     })
 
     it('should error with type = "entity.verify.failed"', function (done) {
-      var server = createServer({ verify: function (req, res, buf) {
-        if (buf[0] === 0x5b) throw new Error('no arrays')
-      } })
+      var server = createServer({
+        verify: function (req, res, buf) {
+          if (buf[0] === 0x5b) throw new Error('no arrays')
+        }
+      })
 
       request(server)
         .post('/')
@@ -415,12 +428,14 @@ describe('bodyParser.json()', function () {
     })
 
     it('should allow custom codes', function (done) {
-      var server = createServer({ verify: function (req, res, buf) {
-        if (buf[0] !== 0x5b) return
-        var err = new Error('no arrays')
-        err.status = 400
-        throw err
-      } })
+      var server = createServer({
+        verify: function (req, res, buf) {
+          if (buf[0] !== 0x5b) return
+          var err = new Error('no arrays')
+          err.status = 400
+          throw err
+        }
+      })
 
       request(server)
         .post('/')
@@ -430,12 +445,14 @@ describe('bodyParser.json()', function () {
     })
 
     it('should allow custom type', function (done) {
-      var server = createServer({ verify: function (req, res, buf) {
-        if (buf[0] !== 0x5b) return
-        var err = new Error('no arrays')
-        err.type = 'foo.bar'
-        throw err
-      } })
+      var server = createServer({
+        verify: function (req, res, buf) {
+          if (buf[0] !== 0x5b) return
+          var err = new Error('no arrays')
+          err.type = 'foo.bar'
+          throw err
+        }
+      })
 
       request(server)
         .post('/')
@@ -446,9 +463,11 @@ describe('bodyParser.json()', function () {
     })
 
     it('should include original body on error object', function (done) {
-      var server = createServer({ verify: function (req, res, buf) {
-        if (buf[0] === 0x5b) throw new Error('no arrays')
-      } })
+      var server = createServer({
+        verify: function (req, res, buf) {
+          if (buf[0] === 0x5b) throw new Error('no arrays')
+        }
+      })
 
       request(server)
         .post('/')
@@ -459,9 +478,11 @@ describe('bodyParser.json()', function () {
     })
 
     it('should allow pass-through', function (done) {
-      var server = createServer({ verify: function (req, res, buf) {
-        if (buf[0] === 0x5b) throw new Error('no arrays')
-      } })
+      var server = createServer({
+        verify: function (req, res, buf) {
+          if (buf[0] === 0x5b) throw new Error('no arrays')
+        }
+      })
 
       request(server)
         .post('/')
@@ -471,9 +492,11 @@ describe('bodyParser.json()', function () {
     })
 
     it('should work with different charsets', function (done) {
-      var server = createServer({ verify: function (req, res, buf) {
-        if (buf[0] === 0x5b) throw new Error('no arrays')
-      } })
+      var server = createServer({
+        verify: function (req, res, buf) {
+          if (buf[0] === 0x5b) throw new Error('no arrays')
+        }
+      })
 
       var test = request(server).post('/')
       test.set('Content-Type', 'application/json; charset=utf-16')
@@ -482,9 +505,11 @@ describe('bodyParser.json()', function () {
     })
 
     it('should 415 on unknown charset prior to verify', function (done) {
-      var server = createServer({ verify: function (req, res, buf) {
-        throw new Error('unexpected verify call')
-      } })
+      var server = createServer({
+        verify: function (req, res, buf) {
+          throw new Error('unexpected verify call')
+        }
+      })
 
       var test = request(server).post('/')
       test.set('Content-Type', 'application/json; charset=x-bogus')
